#[repr(u32)]pub enum TextAffinity {
Upstream = 0,
Downstream = 1,
}Expand description
Whether a TextPosition is visually upstream or downstream of its offset.
For example, when a text position exists at a line break, a single offset has two visual positions, one prior to the line break (at the end of the first line) and one after the line break (at the start of the second line). A text affinity disambiguates between those cases. (Something similar happens with between runs of bidirectional text.)
We do not expect new values to be added to this enum.
Variants