pub struct InputMethodEditorDispatchKey3Request {
pub event: KeyEvent,
}Fields
event: KeyEventTrait Implementations
Sourceimpl Clone for InputMethodEditorDispatchKey3Request
impl Clone for InputMethodEditorDispatchKey3Request
Sourcefn clone(&self) -> InputMethodEditorDispatchKey3Request
fn clone(&self) -> InputMethodEditorDispatchKey3Request
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<InputMethodEditorDispatchKey3Request<'static>, ___E> for InputMethodEditorDispatchKey3Requestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<InputMethodEditorDispatchKey3Request<'static>, ___E> for InputMethodEditorDispatchKey3Requestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Request<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Request<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<InputMethodEditorDispatchKey3Request<'static>, ___E> for &'a InputMethodEditorDispatchKey3Requestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<InputMethodEditorDispatchKey3Request<'static>, ___E> for &'a InputMethodEditorDispatchKey3Requestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Request<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Request<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InputMethodEditorDispatchKey3Request<'static>>, ___E> for InputMethodEditorDispatchKey3Requestwhere
___E: Encoder + ?Sized,
InputMethodEditorDispatchKey3Request: Encode<InputMethodEditorDispatchKey3Request<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, InputMethodEditorDispatchKey3Request<'static>>, ___E> for InputMethodEditorDispatchKey3Requestwhere
___E: Encoder + ?Sized,
InputMethodEditorDispatchKey3Request: Encode<InputMethodEditorDispatchKey3Request<'static>, ___E>,
Sourcefn encode_option(
this: Option<InputMethodEditorDispatchKey3Request>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputMethodEditorDispatchKey3Request<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<InputMethodEditorDispatchKey3Request>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputMethodEditorDispatchKey3Request<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InputMethodEditorDispatchKey3Request<'static>>, ___E> for &'a InputMethodEditorDispatchKey3Requestwhere
___E: Encoder + ?Sized,
&'a InputMethodEditorDispatchKey3Request: Encode<InputMethodEditorDispatchKey3Request<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, InputMethodEditorDispatchKey3Request<'static>>, ___E> for &'a InputMethodEditorDispatchKey3Requestwhere
___E: Encoder + ?Sized,
&'a InputMethodEditorDispatchKey3Request: Encode<InputMethodEditorDispatchKey3Request<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a InputMethodEditorDispatchKey3Request>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputMethodEditorDispatchKey3Request<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a InputMethodEditorDispatchKey3Request>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputMethodEditorDispatchKey3Request<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<InputMethodEditorDispatchKey3Request<'de>> for InputMethodEditorDispatchKey3Request
impl<'de> FromWire<InputMethodEditorDispatchKey3Request<'de>> for InputMethodEditorDispatchKey3Request
Sourcefn from_wire(
wire: InputMethodEditorDispatchKey3Request<'de>,
) -> InputMethodEditorDispatchKey3Request
fn from_wire( wire: InputMethodEditorDispatchKey3Request<'de>, ) -> InputMethodEditorDispatchKey3Request
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InputMethodEditorDispatchKey3Request<'de>> for InputMethodEditorDispatchKey3Request
impl<'de> FromWireRef<InputMethodEditorDispatchKey3Request<'de>> for InputMethodEditorDispatchKey3Request
Sourcefn from_wire_ref(
wire: &InputMethodEditorDispatchKey3Request<'de>,
) -> InputMethodEditorDispatchKey3Request
fn from_wire_ref( wire: &InputMethodEditorDispatchKey3Request<'de>, ) -> InputMethodEditorDispatchKey3Request
Converts the given reference to this type.
impl StructuralPartialEq for InputMethodEditorDispatchKey3Request