#[repr(u32)]pub enum InputMethodAction {
Unspecified = 0,
None = 1,
Go = 2,
Search = 3,
Send = 4,
Next = 5,
Done = 6,
Previous = 7,
Newline = 8,
UnknownOrdinal_(u32),
}Expand description
Determines what happens if the “action” key is pressed on the keyboard, typically would either be the “Enter” key on a physical keyboard, or an action button on a virtual keyboard, which is usually placed where Enter would be, but with a custom label.
Variants
Unspecified = 0
None = 1
Go = 2
Search = 3
Send = 4
Next = 5
Done = 6
Previous = 7
Newline = 8
UnknownOrdinal_(u32)