#[repr(u32)]pub enum KeyboardType {
Text = 0,
Number = 1,
Phone = 2,
Datetime = 3,
Multiline = 4,
UnknownOrdinal_(u32),
}Expand description
Requests a specific keyboard type from the text editing subsystem.
This is most relevant for virtual keyboards which have some leeway in how the keyboard is presented to the user, as well as which input is acceptable.
For example, a NUMBER keyboard type may only allow decimal numbers to be
entered. In addition, a virtual keyboard might only show a numeric keypad
for text entry.
Variants