pub struct InputReport {
pub event_time: u64,
pub keyboard: Option<Box<KeyboardReport>>,
pub media_buttons: Option<Box<MediaButtonsReport>>,
pub mouse: Option<Box<MouseReport>>,
pub stylus: Option<Box<StylusReport>>,
pub touchscreen: Option<Box<TouchscreenReport>>,
pub sensor: Option<Box<SensorReport>>,
pub trace_id: u64,
}Fields
event_time: u64keyboard: Option<Box<KeyboardReport>>mouse: Option<Box<MouseReport>>stylus: Option<Box<StylusReport>>touchscreen: Option<Box<TouchscreenReport>>sensor: Option<Box<SensorReport>>trace_id: u64Trait Implementations
Sourceimpl Clone for InputReport
impl Clone for InputReport
Sourcefn clone(&self) -> InputReport
fn clone(&self) -> InputReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputReport
impl Debug for InputReport
Sourceimpl<___E> Encode<InputReport<'static>, ___E> for InputReportwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<InputReport<'static>, ___E> for InputReportwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<InputReport<'static>, ___E> for &'a InputReportwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<InputReport<'static>, ___E> for &'a InputReportwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InputReport<'static>>, ___E> for InputReport
impl<___E> EncodeOption<Box<'static, InputReport<'static>>, ___E> for InputReport
Sourcefn encode_option(
this: Option<InputReport>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputReport<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<InputReport>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputReport<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InputReport<'static>>, ___E> for &'a InputReport
impl<'a, ___E> EncodeOption<Box<'static, InputReport<'static>>, ___E> for &'a InputReport
Sourcefn encode_option(
this: Option<&'a InputReport>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputReport<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a InputReport>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputReport<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for InputReport
Sourceimpl<'de> FromWire<InputReport<'de>> for InputReport
impl<'de> FromWire<InputReport<'de>> for InputReport
Sourcefn from_wire(wire: InputReport<'de>) -> InputReport
fn from_wire(wire: InputReport<'de>) -> InputReport
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InputReport<'de>> for InputReport
impl<'de> FromWireRef<InputReport<'de>> for InputReport
Sourcefn from_wire_ref(wire: &InputReport<'de>) -> InputReport
fn from_wire_ref(wire: &InputReport<'de>) -> InputReport
Converts the given reference to this type.
Sourceimpl Hash for InputReport
impl Hash for InputReport
Sourceimpl Ord for InputReport
impl Ord for InputReport
Sourcefn cmp(&self, other: &InputReport) -> Ordering
fn cmp(&self, other: &InputReport) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for InputReport
impl PartialEq for InputReport
Sourceimpl PartialOrd for InputReport
impl PartialOrd for InputReport
impl StructuralPartialEq for InputReport