#[repr(C)]pub struct MediaButtonsReport {
pub volume_up: bool,
pub volume_down: bool,
pub mic_mute: bool,
pub reset: bool,
pub pause: bool,
pub camera_disable: bool,
}Expand description
MediaButtonsReport describes the media buttons event delivered from the event stream.
Each bool in the report represents a single button where true means the button
is being pressed. A single report should be sent on every state change.
Fields
volume_up: boolvolume_down: boolmic_mute: boolreset: boolpause: boolcamera_disable: boolTrait Implementations
Sourceimpl Clone for MediaButtonsReport
impl Clone for MediaButtonsReport
Sourcefn clone(&self) -> MediaButtonsReport
fn clone(&self) -> MediaButtonsReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MediaButtonsReport
Sourceimpl Debug for MediaButtonsReport
impl Debug for MediaButtonsReport
Sourceimpl<___E> Encode<MediaButtonsReport, ___E> for MediaButtonsReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MediaButtonsReport, ___E> for MediaButtonsReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<MediaButtonsReport, MediaButtonsReport>
const COPY_OPTIMIZATION: CopyOptimization<MediaButtonsReport, MediaButtonsReport>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MediaButtonsReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MediaButtonsReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<MediaButtonsReport, ___E> for &'a MediaButtonsReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MediaButtonsReport, ___E> for &'a MediaButtonsReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MediaButtonsReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MediaButtonsReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, MediaButtonsReport>, ___E> for MediaButtonsReport
impl<___E> EncodeOption<Box<'static, MediaButtonsReport>, ___E> for MediaButtonsReport
Sourcefn encode_option(
this: Option<MediaButtonsReport>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MediaButtonsReport>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<MediaButtonsReport>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MediaButtonsReport>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MediaButtonsReport>, ___E> for &'a MediaButtonsReport
impl<'a, ___E> EncodeOption<Box<'static, MediaButtonsReport>, ___E> for &'a MediaButtonsReport
Sourcefn encode_option(
this: Option<&'a MediaButtonsReport>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MediaButtonsReport>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a MediaButtonsReport>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MediaButtonsReport>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for MediaButtonsReport
Sourceimpl FromWire<MediaButtonsReport> for MediaButtonsReport
impl FromWire<MediaButtonsReport> for MediaButtonsReport
Sourceconst COPY_OPTIMIZATION: CopyOptimization<MediaButtonsReport, MediaButtonsReport>
const COPY_OPTIMIZATION: CopyOptimization<MediaButtonsReport, MediaButtonsReport>
Sourcefn from_wire(wire: MediaButtonsReport) -> MediaButtonsReport
fn from_wire(wire: MediaButtonsReport) -> MediaButtonsReport
Converts the given owned value to this type.
Sourceimpl FromWireRef<MediaButtonsReport> for MediaButtonsReport
impl FromWireRef<MediaButtonsReport> for MediaButtonsReport
Sourcefn from_wire_ref(wire: &MediaButtonsReport) -> MediaButtonsReport
fn from_wire_ref(wire: &MediaButtonsReport) -> MediaButtonsReport
Converts the given reference to this type.
Sourceimpl Hash for MediaButtonsReport
impl Hash for MediaButtonsReport
Sourceimpl Ord for MediaButtonsReport
impl Ord for MediaButtonsReport
Sourcefn cmp(&self, other: &MediaButtonsReport) -> Ordering
fn cmp(&self, other: &MediaButtonsReport) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for MediaButtonsReport
impl PartialEq for MediaButtonsReport
Sourceimpl PartialOrd for MediaButtonsReport
impl PartialOrd for MediaButtonsReport
impl StructuralPartialEq for MediaButtonsReport