pub struct SendKeyboardInputCmd {
pub compositor_id: u32,
pub keyboard_event: KeyboardEvent,
}Fields
compositor_id: u32keyboard_event: KeyboardEventTrait Implementations
Sourceimpl Clone for SendKeyboardInputCmd
impl Clone for SendKeyboardInputCmd
Sourcefn clone(&self) -> SendKeyboardInputCmd
fn clone(&self) -> SendKeyboardInputCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SendKeyboardInputCmd
Sourceimpl Debug for SendKeyboardInputCmd
impl Debug for SendKeyboardInputCmd
Sourceimpl<___E> Encode<SendKeyboardInputCmd, ___E> for SendKeyboardInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SendKeyboardInputCmd, ___E> for SendKeyboardInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendKeyboardInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendKeyboardInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<SendKeyboardInputCmd, ___E> for &'a SendKeyboardInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SendKeyboardInputCmd, ___E> for &'a SendKeyboardInputCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SendKeyboardInputCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SendKeyboardInputCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SendKeyboardInputCmd>, ___E> for SendKeyboardInputCmd
impl<___E> EncodeOption<Box<'static, SendKeyboardInputCmd>, ___E> for SendKeyboardInputCmd
Sourcefn encode_option(
this: Option<SendKeyboardInputCmd>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SendKeyboardInputCmd>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SendKeyboardInputCmd>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SendKeyboardInputCmd>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SendKeyboardInputCmd>, ___E> for &'a SendKeyboardInputCmd
impl<'a, ___E> EncodeOption<Box<'static, SendKeyboardInputCmd>, ___E> for &'a SendKeyboardInputCmd
Sourcefn encode_option(
this: Option<&'a SendKeyboardInputCmd>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SendKeyboardInputCmd>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SendKeyboardInputCmd>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SendKeyboardInputCmd>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for SendKeyboardInputCmd
Sourceimpl FromWire<SendKeyboardInputCmd> for SendKeyboardInputCmd
impl FromWire<SendKeyboardInputCmd> for SendKeyboardInputCmd
Sourcefn from_wire(wire: SendKeyboardInputCmd) -> SendKeyboardInputCmd
fn from_wire(wire: SendKeyboardInputCmd) -> SendKeyboardInputCmd
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SendKeyboardInputCmd> for SendKeyboardInputCmd
impl FromWireRef<SendKeyboardInputCmd> for SendKeyboardInputCmd
Sourcefn from_wire_ref(wire: &SendKeyboardInputCmd) -> SendKeyboardInputCmd
fn from_wire_ref(wire: &SendKeyboardInputCmd) -> SendKeyboardInputCmd
Converts the given reference to this type.
Sourceimpl Hash for SendKeyboardInputCmd
impl Hash for SendKeyboardInputCmd
Sourceimpl Ord for SendKeyboardInputCmd
impl Ord for SendKeyboardInputCmd
Sourcefn cmp(&self, other: &SendKeyboardInputCmd) -> Ordering
fn cmp(&self, other: &SendKeyboardInputCmd) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for SendKeyboardInputCmd
impl PartialEq for SendKeyboardInputCmd
Sourceimpl PartialOrd for SendKeyboardInputCmd
impl PartialOrd for SendKeyboardInputCmd
impl StructuralPartialEq for SendKeyboardInputCmd