pub struct TextInputState {
pub revision: u32,
pub text: String,
pub selection: TextSelection,
pub composing: TextRange,
}Expand description
The current text, selection, and composing state for editing a run of text.
Fields
revision: u32text: Stringselection: TextSelectioncomposing: TextRangeTrait Implementations
Sourceimpl Clone for TextInputState
impl Clone for TextInputState
Sourcefn clone(&self) -> TextInputState
fn clone(&self) -> TextInputState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextInputState
impl Debug for TextInputState
Sourceimpl<___E> Encode<TextInputState<'static>, ___E> for TextInputStatewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TextInputState<'static>, ___E> for TextInputStatewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TextInputState<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TextInputState<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<TextInputState<'static>, ___E> for &'a TextInputStatewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TextInputState<'static>, ___E> for &'a TextInputStatewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TextInputState<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TextInputState<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, TextInputState<'static>>, ___E> for TextInputState
impl<___E> EncodeOption<Box<'static, TextInputState<'static>>, ___E> for TextInputState
Sourcefn encode_option(
this: Option<TextInputState>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TextInputState<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TextInputState>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TextInputState<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TextInputState<'static>>, ___E> for &'a TextInputState
impl<'a, ___E> EncodeOption<Box<'static, TextInputState<'static>>, ___E> for &'a TextInputState
Sourcefn encode_option(
this: Option<&'a TextInputState>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TextInputState<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TextInputState>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TextInputState<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for TextInputState
Sourceimpl<'de> FromWire<TextInputState<'de>> for TextInputState
impl<'de> FromWire<TextInputState<'de>> for TextInputState
Sourcefn from_wire(wire: TextInputState<'de>) -> TextInputState
fn from_wire(wire: TextInputState<'de>) -> TextInputState
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TextInputState<'de>> for TextInputState
impl<'de> FromWireRef<TextInputState<'de>> for TextInputState
Sourcefn from_wire_ref(wire: &TextInputState<'de>) -> TextInputState
fn from_wire_ref(wire: &TextInputState<'de>) -> TextInputState
Converts the given reference to this type.
Sourceimpl Hash for TextInputState
impl Hash for TextInputState
Sourceimpl Ord for TextInputState
impl Ord for TextInputState
Sourcefn cmp(&self, other: &TextInputState) -> Ordering
fn cmp(&self, other: &TextInputState) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for TextInputState
impl PartialEq for TextInputState
Sourceimpl PartialOrd for TextInputState
impl PartialOrd for TextInputState
impl StructuralPartialEq for TextInputState