pub struct InputDeviceDispatchReportRequest {
pub report: InputReport,
}Fields
report: InputReportTrait Implementations
Sourceimpl Clone for InputDeviceDispatchReportRequest
impl Clone for InputDeviceDispatchReportRequest
Sourcefn clone(&self) -> InputDeviceDispatchReportRequest
fn clone(&self) -> InputDeviceDispatchReportRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<InputDeviceDispatchReportRequest<'static>, ___E> for InputDeviceDispatchReportRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<InputDeviceDispatchReportRequest<'static>, ___E> for InputDeviceDispatchReportRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceDispatchReportRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceDispatchReportRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<InputDeviceDispatchReportRequest<'static>, ___E> for &'a InputDeviceDispatchReportRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<InputDeviceDispatchReportRequest<'static>, ___E> for &'a InputDeviceDispatchReportRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceDispatchReportRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceDispatchReportRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InputDeviceDispatchReportRequest<'static>>, ___E> for InputDeviceDispatchReportRequestwhere
___E: Encoder + ?Sized,
InputDeviceDispatchReportRequest: Encode<InputDeviceDispatchReportRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, InputDeviceDispatchReportRequest<'static>>, ___E> for InputDeviceDispatchReportRequestwhere
___E: Encoder + ?Sized,
InputDeviceDispatchReportRequest: Encode<InputDeviceDispatchReportRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<InputDeviceDispatchReportRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputDeviceDispatchReportRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<InputDeviceDispatchReportRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputDeviceDispatchReportRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InputDeviceDispatchReportRequest<'static>>, ___E> for &'a InputDeviceDispatchReportRequestwhere
___E: Encoder + ?Sized,
&'a InputDeviceDispatchReportRequest: Encode<InputDeviceDispatchReportRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, InputDeviceDispatchReportRequest<'static>>, ___E> for &'a InputDeviceDispatchReportRequestwhere
___E: Encoder + ?Sized,
&'a InputDeviceDispatchReportRequest: Encode<InputDeviceDispatchReportRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a InputDeviceDispatchReportRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputDeviceDispatchReportRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a InputDeviceDispatchReportRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputDeviceDispatchReportRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for InputDeviceDispatchReportRequest
Sourceimpl<'de> FromWire<InputDeviceDispatchReportRequest<'de>> for InputDeviceDispatchReportRequest
impl<'de> FromWire<InputDeviceDispatchReportRequest<'de>> for InputDeviceDispatchReportRequest
Sourcefn from_wire(
wire: InputDeviceDispatchReportRequest<'de>,
) -> InputDeviceDispatchReportRequest
fn from_wire( wire: InputDeviceDispatchReportRequest<'de>, ) -> InputDeviceDispatchReportRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InputDeviceDispatchReportRequest<'de>> for InputDeviceDispatchReportRequest
impl<'de> FromWireRef<InputDeviceDispatchReportRequest<'de>> for InputDeviceDispatchReportRequest
Sourcefn from_wire_ref(
wire: &InputDeviceDispatchReportRequest<'de>,
) -> InputDeviceDispatchReportRequest
fn from_wire_ref( wire: &InputDeviceDispatchReportRequest<'de>, ) -> InputDeviceDispatchReportRequest
Converts the given reference to this type.
Sourceimpl Ord for InputDeviceDispatchReportRequest
impl Ord for InputDeviceDispatchReportRequest
Sourcefn cmp(&self, other: &InputDeviceDispatchReportRequest) -> Ordering
fn cmp(&self, other: &InputDeviceDispatchReportRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for InputDeviceDispatchReportRequest
impl PartialOrd for InputDeviceDispatchReportRequest
impl StructuralPartialEq for InputDeviceDispatchReportRequest