pub struct InputMethodEditorClientDidUpdateStateRequest {
pub state: TextInputState,
pub event: Option<Box<InputEvent>>,
}Fields
state: TextInputStateevent: Option<Box<InputEvent>>Trait Implementations
Sourceimpl Clone for InputMethodEditorClientDidUpdateStateRequest
impl Clone for InputMethodEditorClientDidUpdateStateRequest
Sourcefn clone(&self) -> InputMethodEditorClientDidUpdateStateRequest
fn clone(&self) -> InputMethodEditorClientDidUpdateStateRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<InputMethodEditorClientDidUpdateStateRequest<'static>, ___E> for InputMethodEditorClientDidUpdateStateRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<InputMethodEditorClientDidUpdateStateRequest<'static>, ___E> for InputMethodEditorClientDidUpdateStateRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorClientDidUpdateStateRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorClientDidUpdateStateRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<InputMethodEditorClientDidUpdateStateRequest<'static>, ___E> for &'a InputMethodEditorClientDidUpdateStateRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<InputMethodEditorClientDidUpdateStateRequest<'static>, ___E> for &'a InputMethodEditorClientDidUpdateStateRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorClientDidUpdateStateRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorClientDidUpdateStateRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InputMethodEditorClientDidUpdateStateRequest<'static>>, ___E> for InputMethodEditorClientDidUpdateStateRequestwhere
___E: Encoder + ?Sized,
InputMethodEditorClientDidUpdateStateRequest: Encode<InputMethodEditorClientDidUpdateStateRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, InputMethodEditorClientDidUpdateStateRequest<'static>>, ___E> for InputMethodEditorClientDidUpdateStateRequestwhere
___E: Encoder + ?Sized,
InputMethodEditorClientDidUpdateStateRequest: Encode<InputMethodEditorClientDidUpdateStateRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<InputMethodEditorClientDidUpdateStateRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputMethodEditorClientDidUpdateStateRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<InputMethodEditorClientDidUpdateStateRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputMethodEditorClientDidUpdateStateRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InputMethodEditorClientDidUpdateStateRequest<'static>>, ___E> for &'a InputMethodEditorClientDidUpdateStateRequestwhere
___E: Encoder + ?Sized,
&'a InputMethodEditorClientDidUpdateStateRequest: Encode<InputMethodEditorClientDidUpdateStateRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, InputMethodEditorClientDidUpdateStateRequest<'static>>, ___E> for &'a InputMethodEditorClientDidUpdateStateRequestwhere
___E: Encoder + ?Sized,
&'a InputMethodEditorClientDidUpdateStateRequest: Encode<InputMethodEditorClientDidUpdateStateRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a InputMethodEditorClientDidUpdateStateRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputMethodEditorClientDidUpdateStateRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a InputMethodEditorClientDidUpdateStateRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputMethodEditorClientDidUpdateStateRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<InputMethodEditorClientDidUpdateStateRequest<'de>> for InputMethodEditorClientDidUpdateStateRequest
impl<'de> FromWire<InputMethodEditorClientDidUpdateStateRequest<'de>> for InputMethodEditorClientDidUpdateStateRequest
Sourcefn from_wire(
wire: InputMethodEditorClientDidUpdateStateRequest<'de>,
) -> InputMethodEditorClientDidUpdateStateRequest
fn from_wire( wire: InputMethodEditorClientDidUpdateStateRequest<'de>, ) -> InputMethodEditorClientDidUpdateStateRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InputMethodEditorClientDidUpdateStateRequest<'de>> for InputMethodEditorClientDidUpdateStateRequest
impl<'de> FromWireRef<InputMethodEditorClientDidUpdateStateRequest<'de>> for InputMethodEditorClientDidUpdateStateRequest
Sourcefn from_wire_ref(
wire: &InputMethodEditorClientDidUpdateStateRequest<'de>,
) -> InputMethodEditorClientDidUpdateStateRequest
fn from_wire_ref( wire: &InputMethodEditorClientDidUpdateStateRequest<'de>, ) -> InputMethodEditorClientDidUpdateStateRequest
Converts the given reference to this type.
Sourceimpl PartialOrd for InputMethodEditorClientDidUpdateStateRequest
impl PartialOrd for InputMethodEditorClientDidUpdateStateRequest
Sourcefn partial_cmp(
&self,
other: &InputMethodEditorClientDidUpdateStateRequest,
) -> Option<Ordering>
fn partial_cmp( &self, other: &InputMethodEditorClientDidUpdateStateRequest, ) -> Option<Ordering>
impl StructuralPartialEq for InputMethodEditorClientDidUpdateStateRequest