pub struct KeyboardEvent {
pub event_time: u64,
pub device_id: u32,
pub phase: KeyboardEventPhase,
pub hid_usage: u32,
pub code_point: u32,
pub modifiers: u32,
}Expand description
KeyboardEvent represents event generated by a user’s interaction with a
keyboard.
Those events are triggered by distinct pressed state changes of the keys.
The state transitions should be as follows: PRESSED -> (REPEAT ->) RELEASED or PRESSED -> (REPEAT ->) CANCELLED
The input system will repeat those events automatically when a code_point is available.
DEPRECATED: Will be removed in favor of fuchsia.ui.input.KeyEvent.
Fields
event_time: u64device_id: u32phase: KeyboardEventPhasehid_usage: u32code_point: u32modifiers: u32Trait Implementations
Sourceimpl Clone for KeyboardEvent
impl Clone for KeyboardEvent
Sourcefn clone(&self) -> KeyboardEvent
fn clone(&self) -> KeyboardEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for KeyboardEvent
Sourceimpl Debug for KeyboardEvent
impl Debug for KeyboardEvent
Sourceimpl<___E> Encode<KeyboardEvent, ___E> for KeyboardEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<KeyboardEvent, ___E> for KeyboardEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyboardEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyboardEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<KeyboardEvent, ___E> for &'a KeyboardEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<KeyboardEvent, ___E> for &'a KeyboardEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyboardEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyboardEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, KeyboardEvent>, ___E> for KeyboardEvent
impl<___E> EncodeOption<Box<'static, KeyboardEvent>, ___E> for KeyboardEvent
Sourcefn encode_option(
this: Option<KeyboardEvent>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, KeyboardEvent>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<KeyboardEvent>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, KeyboardEvent>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, KeyboardEvent>, ___E> for &'a KeyboardEvent
impl<'a, ___E> EncodeOption<Box<'static, KeyboardEvent>, ___E> for &'a KeyboardEvent
Sourcefn encode_option(
this: Option<&'a KeyboardEvent>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, KeyboardEvent>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a KeyboardEvent>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, KeyboardEvent>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for KeyboardEvent
Sourceimpl FromWire<KeyboardEvent> for KeyboardEvent
impl FromWire<KeyboardEvent> for KeyboardEvent
Sourcefn from_wire(wire: KeyboardEvent) -> KeyboardEvent
fn from_wire(wire: KeyboardEvent) -> KeyboardEvent
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<KeyboardEvent> for KeyboardEvent
impl FromWireRef<KeyboardEvent> for KeyboardEvent
Sourcefn from_wire_ref(wire: &KeyboardEvent) -> KeyboardEvent
fn from_wire_ref(wire: &KeyboardEvent) -> KeyboardEvent
Converts the given reference to this type.
Sourceimpl Hash for KeyboardEvent
impl Hash for KeyboardEvent
Sourceimpl Ord for KeyboardEvent
impl Ord for KeyboardEvent
Sourcefn cmp(&self, other: &KeyboardEvent) -> Ordering
fn cmp(&self, other: &KeyboardEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for KeyboardEvent
impl PartialEq for KeyboardEvent
Sourceimpl PartialOrd for KeyboardEvent
impl PartialOrd for KeyboardEvent
impl StructuralPartialEq for KeyboardEvent