#[repr(C)]pub struct SetHardKeyboardDeliveryCmd {
pub delivery_request: bool,
}Fields
delivery_request: boolTrait Implementations
Sourceimpl Clone for SetHardKeyboardDeliveryCmd
impl Clone for SetHardKeyboardDeliveryCmd
Sourcefn clone(&self) -> SetHardKeyboardDeliveryCmd
fn clone(&self) -> SetHardKeyboardDeliveryCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SetHardKeyboardDeliveryCmd
Sourceimpl Debug for SetHardKeyboardDeliveryCmd
impl Debug for SetHardKeyboardDeliveryCmd
Sourceimpl<___E> Encode<SetHardKeyboardDeliveryCmd, ___E> for SetHardKeyboardDeliveryCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SetHardKeyboardDeliveryCmd, ___E> for SetHardKeyboardDeliveryCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SetHardKeyboardDeliveryCmd, SetHardKeyboardDeliveryCmd>
const COPY_OPTIMIZATION: CopyOptimization<SetHardKeyboardDeliveryCmd, SetHardKeyboardDeliveryCmd>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SetHardKeyboardDeliveryCmd, ___E> for &'a SetHardKeyboardDeliveryCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SetHardKeyboardDeliveryCmd, ___E> for &'a SetHardKeyboardDeliveryCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SetHardKeyboardDeliveryCmd>, ___E> for SetHardKeyboardDeliveryCmd
impl<___E> EncodeOption<Box<'static, SetHardKeyboardDeliveryCmd>, ___E> for SetHardKeyboardDeliveryCmd
Sourcefn encode_option(
this: Option<SetHardKeyboardDeliveryCmd>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SetHardKeyboardDeliveryCmd>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SetHardKeyboardDeliveryCmd>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SetHardKeyboardDeliveryCmd>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SetHardKeyboardDeliveryCmd>, ___E> for &'a SetHardKeyboardDeliveryCmdwhere
___E: Encoder + ?Sized,
&'a SetHardKeyboardDeliveryCmd: Encode<SetHardKeyboardDeliveryCmd, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SetHardKeyboardDeliveryCmd>, ___E> for &'a SetHardKeyboardDeliveryCmdwhere
___E: Encoder + ?Sized,
&'a SetHardKeyboardDeliveryCmd: Encode<SetHardKeyboardDeliveryCmd, ___E>,
Sourcefn encode_option(
this: Option<&'a SetHardKeyboardDeliveryCmd>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SetHardKeyboardDeliveryCmd>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SetHardKeyboardDeliveryCmd>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SetHardKeyboardDeliveryCmd>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for SetHardKeyboardDeliveryCmd
Sourceimpl FromWire<SetHardKeyboardDeliveryCmd> for SetHardKeyboardDeliveryCmd
impl FromWire<SetHardKeyboardDeliveryCmd> for SetHardKeyboardDeliveryCmd
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SetHardKeyboardDeliveryCmd, SetHardKeyboardDeliveryCmd>
const COPY_OPTIMIZATION: CopyOptimization<SetHardKeyboardDeliveryCmd, SetHardKeyboardDeliveryCmd>
Sourcefn from_wire(wire: SetHardKeyboardDeliveryCmd) -> SetHardKeyboardDeliveryCmd
fn from_wire(wire: SetHardKeyboardDeliveryCmd) -> SetHardKeyboardDeliveryCmd
Converts the given owned value to this type.
Sourceimpl FromWireRef<SetHardKeyboardDeliveryCmd> for SetHardKeyboardDeliveryCmd
impl FromWireRef<SetHardKeyboardDeliveryCmd> for SetHardKeyboardDeliveryCmd
Sourcefn from_wire_ref(
wire: &SetHardKeyboardDeliveryCmd,
) -> SetHardKeyboardDeliveryCmd
fn from_wire_ref( wire: &SetHardKeyboardDeliveryCmd, ) -> SetHardKeyboardDeliveryCmd
Converts the given reference to this type.
Sourceimpl Hash for SetHardKeyboardDeliveryCmd
impl Hash for SetHardKeyboardDeliveryCmd
Sourceimpl Ord for SetHardKeyboardDeliveryCmd
impl Ord for SetHardKeyboardDeliveryCmd
Sourcefn cmp(&self, other: &SetHardKeyboardDeliveryCmd) -> Ordering
fn cmp(&self, other: &SetHardKeyboardDeliveryCmd) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for SetHardKeyboardDeliveryCmd
impl PartialOrd for SetHardKeyboardDeliveryCmd
impl StructuralPartialEq for SetHardKeyboardDeliveryCmd