#[repr(C)]pub struct FocusEvent {
pub event_time: Uint64,
pub focused: bool,
}Expand description
The wire type corresponding to FocusEvent.
Fields
event_time: Uint64focused: boolTrait Implementations
Sourceimpl Clone for FocusEvent
impl Clone for FocusEvent
Sourcefn clone(&self) -> FocusEvent
fn clone(&self) -> FocusEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for FocusEvent
impl Constrained for FocusEvent
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, FocusEvent>,
_: <FocusEvent as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, FocusEvent>, _: <FocusEvent as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for FocusEvent
impl Debug for FocusEvent
Sourceimpl<___D> Decode<___D> for FocusEventwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for FocusEventwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<FocusEvent, ___E> for FocusEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FocusEvent, ___E> for FocusEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FocusEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FocusEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<FocusEvent, ___E> for &'a FocusEventwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FocusEvent, ___E> for &'a FocusEventwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FocusEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FocusEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<FocusEvent, ___E> for FocusEvent<T0, T1>
impl<___E, T0, T1> Encode<FocusEvent, ___E> for FocusEvent<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FocusEvent>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FocusEvent>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FocusEvent> for FocusEvent
impl FromWire<FocusEvent> for FocusEvent
Sourcefn from_wire(wire: FocusEvent) -> FocusEvent
fn from_wire(wire: FocusEvent) -> FocusEvent
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FocusEvent> for FocusEvent
impl FromWireRef<FocusEvent> for FocusEvent
Sourcefn from_wire_ref(wire: &FocusEvent) -> FocusEvent
fn from_wire_ref(wire: &FocusEvent) -> FocusEvent
Converts the given reference to this type.
Sourceimpl IntoNatural for FocusEvent
impl IntoNatural for FocusEvent
Sourcetype Natural = FocusEvent
type Natural = FocusEvent
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FocusEvent
impl Wire for FocusEvent
Sourcetype Narrowed<'de> = FocusEvent
type Narrowed<'de> = FocusEvent
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<FocusEvent>)
fn zero_padding(out_: &mut MaybeUninit<FocusEvent>)
Writes zeroes to the padding for this type, if any.