#[repr(C)]pub struct InputMethodEditorDispatchKey3Response {
pub handled: bool,
}Expand description
The wire type corresponding to InputMethodEditorDispatchKey3Response.
Fields
handled: boolTrait Implementations
Sourceimpl Clone for InputMethodEditorDispatchKey3Response
impl Clone for InputMethodEditorDispatchKey3Response
Sourcefn clone(&self) -> InputMethodEditorDispatchKey3Response
fn clone(&self) -> InputMethodEditorDispatchKey3Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for InputMethodEditorDispatchKey3Response
impl Constrained for InputMethodEditorDispatchKey3Response
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, InputMethodEditorDispatchKey3Response>,
_: <InputMethodEditorDispatchKey3Response as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, InputMethodEditorDispatchKey3Response>, _: <InputMethodEditorDispatchKey3Response as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for InputMethodEditorDispatchKey3Responsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for InputMethodEditorDispatchKey3Responsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<InputMethodEditorDispatchKey3Response, ___E> for InputMethodEditorDispatchKey3Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InputMethodEditorDispatchKey3Response, ___E> for InputMethodEditorDispatchKey3Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InputMethodEditorDispatchKey3Response, InputMethodEditorDispatchKey3Response>
const COPY_OPTIMIZATION: CopyOptimization<InputMethodEditorDispatchKey3Response, InputMethodEditorDispatchKey3Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<InputMethodEditorDispatchKey3Response, ___E> for &'a InputMethodEditorDispatchKey3Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InputMethodEditorDispatchKey3Response, ___E> for &'a InputMethodEditorDispatchKey3Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<InputMethodEditorDispatchKey3Response, ___E> for InputMethodEditorDispatchKey3Response<T0>
impl<___E, T0> Encode<InputMethodEditorDispatchKey3Response, ___E> for InputMethodEditorDispatchKey3Response<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<InputMethodEditorDispatchKey3Response> for InputMethodEditorDispatchKey3Response
impl FromWire<InputMethodEditorDispatchKey3Response> for InputMethodEditorDispatchKey3Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InputMethodEditorDispatchKey3Response, InputMethodEditorDispatchKey3Response>
const COPY_OPTIMIZATION: CopyOptimization<InputMethodEditorDispatchKey3Response, InputMethodEditorDispatchKey3Response>
Sourcefn from_wire(
wire: InputMethodEditorDispatchKey3Response,
) -> InputMethodEditorDispatchKey3Response
fn from_wire( wire: InputMethodEditorDispatchKey3Response, ) -> InputMethodEditorDispatchKey3Response
Converts the given owned value to this type.
Sourceimpl FromWireRef<InputMethodEditorDispatchKey3Response> for InputMethodEditorDispatchKey3Response
impl FromWireRef<InputMethodEditorDispatchKey3Response> for InputMethodEditorDispatchKey3Response
Sourcefn from_wire_ref(
wire: &InputMethodEditorDispatchKey3Response,
) -> InputMethodEditorDispatchKey3Response
fn from_wire_ref( wire: &InputMethodEditorDispatchKey3Response, ) -> InputMethodEditorDispatchKey3Response
Converts the given reference to this type.
Sourceimpl IntoNatural for InputMethodEditorDispatchKey3Response
impl IntoNatural for InputMethodEditorDispatchKey3Response
Sourcetype Natural = InputMethodEditorDispatchKey3Response
type Natural = InputMethodEditorDispatchKey3Response
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for InputMethodEditorDispatchKey3Response
impl Wire for InputMethodEditorDispatchKey3Response
Sourcetype Narrowed<'de> = InputMethodEditorDispatchKey3Response
type Narrowed<'de> = InputMethodEditorDispatchKey3Response
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>)
fn zero_padding(out_: &mut MaybeUninit<InputMethodEditorDispatchKey3Response>)
Writes zeroes to the padding for this type, if any.