#[repr(C)]pub struct MediaButtonsReport {
pub volume_up: bool,
pub volume_down: bool,
pub mic_mute: bool,
pub reset: bool,
pub pause: bool,
pub camera_disable: bool,
}Expand description
The wire type corresponding to MediaButtonsReport.
Fields
volume_up: boolvolume_down: boolmic_mute: boolreset: boolpause: boolcamera_disable: boolTrait Implementations
Sourceimpl Clone for MediaButtonsReport
impl Clone for MediaButtonsReport
Sourcefn clone(&self) -> MediaButtonsReport
fn clone(&self) -> MediaButtonsReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for MediaButtonsReport
impl Constrained for MediaButtonsReport
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, MediaButtonsReport>,
_: <MediaButtonsReport as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, MediaButtonsReport>, _: <MediaButtonsReport as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for MediaButtonsReport
impl Debug for MediaButtonsReport
Sourceimpl<___D> Decode<___D> for MediaButtonsReportwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for MediaButtonsReportwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<MediaButtonsReport, ___E> for MediaButtonsReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MediaButtonsReport, ___E> for MediaButtonsReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<MediaButtonsReport, MediaButtonsReport>
const COPY_OPTIMIZATION: CopyOptimization<MediaButtonsReport, MediaButtonsReport>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MediaButtonsReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MediaButtonsReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<MediaButtonsReport, ___E> for &'a MediaButtonsReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MediaButtonsReport, ___E> for &'a MediaButtonsReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MediaButtonsReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MediaButtonsReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5> Encode<MediaButtonsReport, ___E> for MediaButtonsReport<T0, T1, T2, T3, T4, T5>
impl<___E, T0, T1, T2, T3, T4, T5> Encode<MediaButtonsReport, ___E> for MediaButtonsReport<T0, T1, T2, T3, T4, T5>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MediaButtonsReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MediaButtonsReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<MediaButtonsReport> for MediaButtonsReport
impl FromWire<MediaButtonsReport> for MediaButtonsReport
Sourceconst COPY_OPTIMIZATION: CopyOptimization<MediaButtonsReport, MediaButtonsReport>
const COPY_OPTIMIZATION: CopyOptimization<MediaButtonsReport, MediaButtonsReport>
Sourcefn from_wire(wire: MediaButtonsReport) -> MediaButtonsReport
fn from_wire(wire: MediaButtonsReport) -> MediaButtonsReport
Converts the given owned value to this type.
Sourceimpl FromWireRef<MediaButtonsReport> for MediaButtonsReport
impl FromWireRef<MediaButtonsReport> for MediaButtonsReport
Sourcefn from_wire_ref(wire: &MediaButtonsReport) -> MediaButtonsReport
fn from_wire_ref(wire: &MediaButtonsReport) -> MediaButtonsReport
Converts the given reference to this type.
Sourceimpl IntoNatural for MediaButtonsReport
impl IntoNatural for MediaButtonsReport
Sourcetype Natural = MediaButtonsReport
type Natural = MediaButtonsReport
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for MediaButtonsReport
impl Wire for MediaButtonsReport
Sourcetype Narrowed<'de> = MediaButtonsReport
type Narrowed<'de> = MediaButtonsReport
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<MediaButtonsReport>)
fn zero_padding(out_: &mut MaybeUninit<MediaButtonsReport>)
Writes zeroes to the padding for this type, if any.