#[repr(C)]pub struct SetHardKeyboardDeliveryCmd {
pub delivery_request: bool,
}Expand description
The wire type corresponding to SetHardKeyboardDeliveryCmd.
Fields
delivery_request: boolTrait Implementations
Sourceimpl Clone for SetHardKeyboardDeliveryCmd
impl Clone for SetHardKeyboardDeliveryCmd
Sourcefn clone(&self) -> SetHardKeyboardDeliveryCmd
fn clone(&self) -> SetHardKeyboardDeliveryCmd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SetHardKeyboardDeliveryCmd
impl Constrained for SetHardKeyboardDeliveryCmd
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SetHardKeyboardDeliveryCmd>,
_: <SetHardKeyboardDeliveryCmd as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SetHardKeyboardDeliveryCmd>, _: <SetHardKeyboardDeliveryCmd as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for SetHardKeyboardDeliveryCmd
impl Debug for SetHardKeyboardDeliveryCmd
Sourceimpl<___D> Decode<___D> for SetHardKeyboardDeliveryCmdwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SetHardKeyboardDeliveryCmdwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<SetHardKeyboardDeliveryCmd, ___E> for SetHardKeyboardDeliveryCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SetHardKeyboardDeliveryCmd, ___E> for SetHardKeyboardDeliveryCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SetHardKeyboardDeliveryCmd, SetHardKeyboardDeliveryCmd>
const COPY_OPTIMIZATION: CopyOptimization<SetHardKeyboardDeliveryCmd, SetHardKeyboardDeliveryCmd>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SetHardKeyboardDeliveryCmd, ___E> for &'a SetHardKeyboardDeliveryCmdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SetHardKeyboardDeliveryCmd, ___E> for &'a SetHardKeyboardDeliveryCmdwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<SetHardKeyboardDeliveryCmd, ___E> for SetHardKeyboardDeliveryCmd<T0>
impl<___E, T0> Encode<SetHardKeyboardDeliveryCmd, ___E> for SetHardKeyboardDeliveryCmd<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SetHardKeyboardDeliveryCmd> for SetHardKeyboardDeliveryCmd
impl FromWire<SetHardKeyboardDeliveryCmd> for SetHardKeyboardDeliveryCmd
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SetHardKeyboardDeliveryCmd, SetHardKeyboardDeliveryCmd>
const COPY_OPTIMIZATION: CopyOptimization<SetHardKeyboardDeliveryCmd, SetHardKeyboardDeliveryCmd>
Sourcefn from_wire(wire: SetHardKeyboardDeliveryCmd) -> SetHardKeyboardDeliveryCmd
fn from_wire(wire: SetHardKeyboardDeliveryCmd) -> SetHardKeyboardDeliveryCmd
Converts the given owned value to this type.
Sourceimpl FromWireRef<SetHardKeyboardDeliveryCmd> for SetHardKeyboardDeliveryCmd
impl FromWireRef<SetHardKeyboardDeliveryCmd> for SetHardKeyboardDeliveryCmd
Sourcefn from_wire_ref(
wire: &SetHardKeyboardDeliveryCmd,
) -> SetHardKeyboardDeliveryCmd
fn from_wire_ref( wire: &SetHardKeyboardDeliveryCmd, ) -> SetHardKeyboardDeliveryCmd
Converts the given reference to this type.
Sourceimpl IntoNatural for SetHardKeyboardDeliveryCmd
impl IntoNatural for SetHardKeyboardDeliveryCmd
Sourcetype Natural = SetHardKeyboardDeliveryCmd
type Natural = SetHardKeyboardDeliveryCmd
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SetHardKeyboardDeliveryCmd
impl Wire for SetHardKeyboardDeliveryCmd
Sourcetype Narrowed<'de> = SetHardKeyboardDeliveryCmd
type Narrowed<'de> = SetHardKeyboardDeliveryCmd
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>)
fn zero_padding(out_: &mut MaybeUninit<SetHardKeyboardDeliveryCmd>)
Writes zeroes to the padding for this type, if any.