#[repr(C)]pub struct StylusReport {
pub x: Int32,
pub y: Int32,
pub pressure: Uint32,
pub is_in_contact: bool,
pub in_range: bool,
pub is_inverted: bool,
pub pressed_buttons: Uint32,
}Expand description
The wire type corresponding to StylusReport.
Fields
x: Int32y: Int32pressure: Uint32is_in_contact: boolin_range: boolis_inverted: boolTrait Implementations
Sourceimpl Clone for StylusReport
impl Clone for StylusReport
Sourcefn clone(&self) -> StylusReport
fn clone(&self) -> StylusReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StylusReport
impl Constrained for StylusReport
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, StylusReport>,
_: <StylusReport as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, StylusReport>, _: <StylusReport as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for StylusReport
impl Debug for StylusReport
Sourceimpl<___D> Decode<___D> for StylusReportwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StylusReportwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<StylusReport, ___E> for StylusReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StylusReport, ___E> for StylusReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StylusReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StylusReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<StylusReport, ___E> for &'a StylusReportwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StylusReport, ___E> for &'a StylusReportwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StylusReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StylusReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5, T6> Encode<StylusReport, ___E> for StylusReport<T0, T1, T2, T3, T4, T5, T6>
impl<___E, T0, T1, T2, T3, T4, T5, T6> Encode<StylusReport, ___E> for StylusReport<T0, T1, T2, T3, T4, T5, T6>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StylusReport>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StylusReport>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StylusReport> for StylusReport
impl FromWire<StylusReport> for StylusReport
Sourcefn from_wire(wire: StylusReport) -> StylusReport
fn from_wire(wire: StylusReport) -> StylusReport
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<StylusReport> for StylusReport
impl FromWireRef<StylusReport> for StylusReport
Sourcefn from_wire_ref(wire: &StylusReport) -> StylusReport
fn from_wire_ref(wire: &StylusReport) -> StylusReport
Converts the given reference to this type.
Sourceimpl IntoNatural for StylusReport
impl IntoNatural for StylusReport
Sourcetype Natural = StylusReport
type Natural = StylusReport
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StylusReport
impl Wire for StylusReport
Sourcetype Narrowed<'de> = StylusReport
type Narrowed<'de> = StylusReport
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<StylusReport>)
fn zero_padding(out_: &mut MaybeUninit<StylusReport>)
Writes zeroes to the padding for this type, if any.