#[repr(C)]pub struct TextSelection {
pub base: Int64,
pub extent: Int64,
pub affinity: TextAffinity,
}Expand description
The wire type corresponding to TextSelection.
Fields
base: Int64extent: Int64affinity: TextAffinityTrait Implementations
Sourceimpl Clone for TextSelection
impl Clone for TextSelection
Sourcefn clone(&self) -> TextSelection
fn clone(&self) -> TextSelection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TextSelection
impl Constrained for TextSelection
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, TextSelection>,
_: <TextSelection as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, TextSelection>, _: <TextSelection as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for TextSelection
impl Debug for TextSelection
Sourceimpl<___D> Decode<___D> for TextSelectionwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TextSelectionwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<TextSelection, ___E> for TextSelectionwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TextSelection, ___E> for TextSelectionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TextSelection>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TextSelection>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<TextSelection, ___E> for &'a TextSelectionwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TextSelection, ___E> for &'a TextSelectionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TextSelection>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TextSelection>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<TextSelection, ___E> for TextSelection<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int64, ___E>,
T1: Encode<Int64, ___E>,
T2: Encode<TextAffinity, ___E>,
impl<___E, T0, T1, T2> Encode<TextSelection, ___E> for TextSelection<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int64, ___E>,
T1: Encode<Int64, ___E>,
T2: Encode<TextAffinity, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TextSelection>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TextSelection>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TextSelection> for TextSelection
impl FromWire<TextSelection> for TextSelection
Sourcefn from_wire(wire: TextSelection) -> TextSelection
fn from_wire(wire: TextSelection) -> TextSelection
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<TextSelection> for TextSelection
impl FromWireRef<TextSelection> for TextSelection
Sourcefn from_wire_ref(wire: &TextSelection) -> TextSelection
fn from_wire_ref(wire: &TextSelection) -> TextSelection
Converts the given reference to this type.
Sourceimpl IntoNatural for TextSelection
impl IntoNatural for TextSelection
Sourcetype Natural = TextSelection
type Natural = TextSelection
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TextSelection
impl Wire for TextSelection
Sourcetype Narrowed<'de> = TextSelection
type Narrowed<'de> = TextSelection
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<TextSelection>)
fn zero_padding(out_: &mut MaybeUninit<TextSelection>)
Writes zeroes to the padding for this type, if any.